summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmsoredit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmsoredit.h')
-rw-r--r--kpovmodeler/pmsoredit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmsoredit.h b/kpovmodeler/pmsoredit.h
index 3858dd11..41cadff1 100644
--- a/kpovmodeler/pmsoredit.h
+++ b/kpovmodeler/pmsoredit.h
@@ -47,9 +47,9 @@ class PMSurfaceOfRevolutionEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSurfaceOfRevolutionEdit with tqparent and name
*/
- PMSurfaceOfRevolutionEdit( TQWidget* tqparent, const char* name = 0 );
+ PMSurfaceOfRevolutionEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -47,9 +47,9 @@ class PMSurfaceOfRevolutionEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMSurfaceOfRevolutionEdit with tqparent and name
+ * Creates a PMSurfaceOfRevolutionEdit with parent and name
*/